@@ -14,7 +14,7 @@ test_that("summarise works", {
 
   DF_L <- x %>%
     group_by(MagicNumber) %>%
-    summarise(nOrders = n())
+    summarise(nOrders = n(), .groups = "drop_last")
 
 
   expect_equal(DF_L[1,2]$nOrders, 11)
@@ -28,7 +28,7 @@ test_that("filter works", {
 
   DF_L <- x %>%
     group_by(MagicNumber) %>%
-    summarise(nOrders = n()) %>%
+    summarise(nOrders = n(), .groups = "drop_last") %>%
     filter(nOrders > num_orders) %>%
     select(MagicNumber) %>%
     as.data.frame() %>%
@@ -36,7 +36,7 @@ test_that("filter works", {
     inner_join(x, by = "MagicNumber") %>%
     group_by(MagicNumber) %>%
     filter(Profit < 0) %>%
-    summarise(Loss = abs(sum(Profit)))
+    summarise(Loss = abs(sum(Profit)), .groups = "drop_last")
 
   expect_gt(sum(DF_L$Loss), expected = 45000)
 
